#! /bin/sh
OBJ_DIR=obj.x86
NAME=usb_joy
DRIVER_PATH=joystick/usb
USER_BIN_PATH=/boot/home/config/add-ons/kernel/drivers/bin
USER_DEV_PATH=/boot/home/config/add-ons/kernel/drivers/dev

REPDESC=/boot/var/tmp/rep_desc.bin
PREFIX=/tmp/usbdiag$$
POKEFILE=$PREFIX.poke.txt
FINDFILE=$PREFIX.find.txt

finish ()
{
	rm -f $PREFIX.*
	exit $1
}

install_driver ()
{
if [ -f $OBJ_DIR/$NAME ]
then
	# make driverinstall
	copyattr --data $OBJ_DIR/$NAME $USER_BIN_PATH/$NAME
	mkdir -p $USER_DEV_PATH/$DRIVER_PATH
	ln -sf $USER_BIN_PATH/$NAME $USER_DEV_PATH/$DRIVER_PATH/$NAME
	copyattr -d -r joysticks /etc
else
	alert --stop "Files are missing." Quit > /dev/null
	finish 1
fi
}

#
# main
#

cd "`dirname \"$0\"`"		# for being called from Tracker

alert --info "Welcome to USB Joystick Wizard.

Installation process includes:

- checking if USB is working
- installing USB Joystick Driver
- testing if your USB Joystick is recognized
- going to Joystick preference
" Quit OK > /dev/null && finish 1

export QUIET=1
./usbdiag.sh || exit 1

if [ -f $USER_BIN_PATH/$NAME ]
then
	alert --info "USB Joystick Driver is already installed. Install anyway?" No Yes > /dev/null && NOINSTALL=1
fi

if [ -z "$NOINSTALL" ]
then
	install_driver
	alert --info "USB Joystick Driver has been installed."
fi

if alert --warning "Do you want to test your USB joystick?" No Yes > /dev/null
then
	alert --info "Done."
	finish 0
fi

alert --info "Unplug your USB joystick(s) if already plugged.
Press OK and wait a while."
sleep 3
find /dev/bus/usb -print > $FINDFILE
rm -f $REPDESC
ls /dev/joystick/usb > /dev/null
alert --info "Plug your USB joystick (only one).
Press OK and wait a while."
for i in 1 2 3 4 5 6 7 8 end
do
	sleep 1
	find /dev/bus/usb -print | cmp -s $FINDFILE - || break
done

if [ $i == end ]
then
	alert --stop "BeOS USB support does not recognize your joystick somehow.

Sorry I cannot help you." Quit > /dev/null
	finish 1
fi

for i in 1 2 3 4 5 6 7 8 end
do
	sleep 1
	[ -c /dev/joystick/usb/0 ] && break
done

if [ -c /dev/joystick/usb/0 ]
then
	alert --info "USB Joystick Driver successfully recognized your joystick.

Press OK to go to Joysticks preference."
	exec /boot/beos/preferences/Joysticks > /dev/null
elif [ -f $REPDESC ]
then
	alert --stop "Sorry, USB Joystick Driver cannot recognize your joystick.

Send $REPDESC file to the author." Quit > /dev/null
	finish 1
else
	alert --stop "Sorry, USB Joystick Driver cannot recognize your joystick." Quit > /dev/null
	finish 1
fi

finish 0
