#include <device/Joystick.h>
#include <support/String.h>
#include <stdio.h>
#include <stdlib.h>
extern "C" {
#include <termcap.h>
}

static char termcap_buf [1024];

void init_termcap (void)
{
	tgetent (termcap_buf, getenv ("TERM"));
}

void do_simple_cap (const char *id)
{
	char buf [1024], *area = buf;

	tgetstr (id, &area);
	fputs (buf, stdout);
	fflush (stdout);
}

#define	home()	do_simple_cap("ho")
#define	cls()	do_simple_cap("cl")

void TestStdMode (BJoystick& joy)
{
	cls ();
	do
	{
		int16 horizontal, vertical;
		bool button1, button2, forceUpdate = true;

		joy.Update ();
		if (joy.horizontal != horizontal ||
			joy.vertical != vertical ||
			joy.button1 != button1 ||
			joy.button2 != button2)
			forceUpdate = true;

		if (forceUpdate)
		{
			home ();
			puts ("Standard mode test: press both buttons to quit");

			horizontal = joy.horizontal;
			vertical = joy.vertical;
			button1 = joy.button1;
			button2 = joy.button2;

			printf ("axes 0 = %6d\n", horizontal);
			printf ("axes 1 = %6d\n", vertical);
			printf ("button 0 = %s\n", button1 ? "off" : "ON ");
			printf ("button 1 = %s\n", button2 ? "off" : "ON ");

			forceUpdate = false;
		}
		snooze (100*1000);
	} while (joy.button1 == true || joy.button2 == true);
}

// joystick_driver.h
#define MAX_AXES 12
#define MAX_HATS 8
#define MAX_BUTTONS 32
#define MAX_STICKS 4

void TestEnhMode (BJoystick& joy)
{
	int i, axes, buttons;
	BString moduleName, deviceName, 
		axisName [MAX_AXES], buttonName [MAX_BUTTONS];
	int16 axesValues [MAX_AXES], prevAxesValues [MAX_AXES];
	uint32 buttonValues;
	bool forceUpdate = true;

	joy.GetControllerModule (&moduleName);
	joy.GetControllerName (&deviceName);
	axes = joy.CountAxes ();
	for (i = 0; i < axes; i++)
		joy.GetAxisNameAt (i, &axisName [i]);
	buttons = joy.CountButtons ();
	for (i = 0; i < buttons; i++)
		joy.GetButtonNameAt (i, &buttonName [i]);

	cls ();
	do
	{
		joy.Update ();

		if (joy.ButtonValues () != buttonValues)
			forceUpdate = true;
		joy.GetAxisValues (axesValues);
		for (i = 0; i < axes; i++)
			if (axesValues [i] != prevAxesValues [i])
			{
				forceUpdate = true;
				break;
			}

		if (forceUpdate)
		{
			home ();
			puts ("Enhanced mode test: press first two buttons to quit");
			printf ("Device: %s\nModule: %s\n\n", 
				deviceName.String(), moduleName.String());

			joy.GetAxisValues (axesValues);
			for (i = 0; i < axes; i++)
			{
				printf ("%s: %6d\n", axisName [i].String(), axesValues [i]);
				prevAxesValues [i] = axesValues [i];
			}

			buttonValues = joy.ButtonValues ();
			for (i = 0; i < buttons; i++)
				printf ("%s: %s\n", buttonName [i].String(), 
					buttonValues & (1 << i) ? "ON " : "off");

			forceUpdate = false;
		}

		snooze (100*1000);
	} while ((buttonValues & 3) != 3);
}

int main (int argc, char **argv)
{
	BJoystick	joy;

	if (argc < 2)
	{
		fputs ("usage: joytest /dev/joystick/foo/bar\n", stderr);
		return 1;
	}

	if (joy.Open (argv [1], false) < 0)
	{
		perror ("open");
		return 1;
	}

	init_termcap ();
	TestStdMode (joy);
	if (joy.EnterEnhancedMode (NULL) == false)
		puts ("Failed to enter enhanced mode.");
	else
		TestEnhMode (joy);

	joy.Close ();
}
