#! /bin/sh

PREFIX=/tmp/usbdiag$$
POKEFILE=$PREFIX.poke.txt
FINDFILE=$PREFIX.find.txt

finish ()
{
	rm -f $PREFIX.*
	exit $1
}

#
# main
#

cd "`dirname \"$0\"`"		# for being called from Tracker

if [ `uname -m` != BePC ]
then
	alert --stop "USBDiag runs on BeOS x86 R5." Quit > /dev/null
	exit 1
fi
case `uname -r` in
5.0)
	;;
3.0|3.1|3.2|4.0|4.1|4.5|4.6)
	alert --stop "USBDiag runs on BeOS x86 R5." Quit > /dev/null
	exit 1
	;;
*)
	alert --warning "USBDiag is not tested on this version of BeOS."
	;;
esac

[ -z "$QUIET" ] && alert --info "Welcome to USBDiag.

USBDiag will diagnose if your computer's USB Host Controller is compatible and working with BeOS.
If you find USB does not work at all, try USBDiag to find solution.

Note that USBDiag does not deal with individual USB peripherals. 
If your problem is specific to a particular USB device, check the driver or application." Quit Next > /dev/null && exit 1

poke > $POKEFILE << END
pci
quit
END

UHC_COUNT=`grep -c 'class_base = 0c class_function = 03 class_api = 00' $POKEFILE`
OHC_COUNT=`grep -c 'class_base = 0c class_function = 03 class_api = 10' $POKEFILE`
PIIX3_DETECTED=`grep -c 'vendor 8086 device 7020' $POKEFILE`
if [ -f /system/add-ons/kernel/busses/usb/uhci ]
then
	UHCD_INSTALLED=1
else
	UHCD_INSTALLED=0
fi
if [ -f /system/add-ons/kernel/busses/usb/ohci ]
then
	OHCD_INSTALLED=1
else
	OHCD_INSTALLED=0
fi
if [ -d /dev/bus/usb/0 ]
then
	USB_WORKING=1
else
	USB_WORKING=0
fi

if [ $UHC_COUNT -eq 0 -a $OHC_COUNT -eq 0 ]
then
	alert --stop "No USB Host Controller detected.
Make sure your USB Host Controller is enabled in BIOS setup." Quit > /dev/null
	finish 1
fi

HC_SUPPORTED=0
HC_UNSUPPORTED=0
if [ $PIIX3_DETECTED -eq 1 ]
then
	alert --warning "Intel PIIX3 (82371SB) detected.

BeOS does not support Universal Host Controller in PIIX3 due to many hardware bugs."
	HC_UNSUPPORTED=1
elif [ $UHC_COUNT -gt 0 ]
then
	[ -z "$QUIET" ] && alert --info "$UHC_COUNT Universal Host Controller(s) detected."
	HC_SUPPORTED=1
fi

if [ $OHC_COUNT -gt 0 ]
then
	if [ $OHCD_INSTALLED -eq 1 ]
	then
		[ -z "$QUIET" ] && alert --info "$OHC_COUNT Open Host Controller(s) detected."
		HC_SUPPORTED=1
	else
		alert --warning "$OHC_COUNT Open Host Controller(s) detected.

BeOS currently does not support Open Host Controller."
		HC_UNSUPPORTED=1
	fi
fi


if [ $USB_WORKING -eq 1 ]
then
	[ -z "$QUIET" ] && alert --info "You have supported USB Host Controller(s) and BeOS USB support is working. USB is available."
elif [ $HC_SUPPORTED -eq 0 ]
then
	alert --stop "You have no supported USB Host Controller(s). USB is unavailable" Quit > /dev/null
	finish 1
else
	alert --stop "You have supported USB Controller(s), but BeOS USB support is not working.
Configure your BIOS setup as follows:

Plug-n-Play OS installed: No
Assign IRQ for USB: Enabled
USB legacy support: Enabled
" Quit > /dev/null
	finish 1
fi

finish 0
